==> miktex-2.9.7440.tar.xz: miktex-2.9.7440/cmake/modules/ConfigNames.cmake <==
## ConfigNames.cmake
##
## Copyright (C) 2017-2020 Christian Schenk
## 
## This file is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; either version 2, or (at your
## option) any later version.
## 
## This file is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this file; if not, write to the Free Software
## Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
## USA.

set(MIKTEX_CONFIG_SECTION_BIBTEX "BibTeX")
set(MIKTEX_CONFIG_SECTION_CORE "Core")
set(MIKTEX_CONFIG_SECTION_CORE_FILETYPES "${MIKTEX_CONFIG_SECTION_CORE}.FileTypes")
set(MIKTEX_CONFIG_SECTION_GENERAL "General")
set(MIKTEX_CONFIG_SECTION_MAKEBASE "MakeBase")
set(MIKTEX_CONFIG_SECTION_MAKEFMT "MakeFMT")
set(MIKTEX_CONFIG_SECTION_MAKEPK "MakePk")
set(MIKTEX_CONFIG_SECTION_MAKETFM "MakeTFM")
set(MIKTEX_CONFIG_SECTION_MPM "MPM")
set(MIKTEX_CONFIG_SECTION_SETUP "Setup")
set(MIKTEX_CONFIG_SECTION_TEXANDFRIENDS "TeXandFriends")

set(MIKTEX_CONFIG_VALUE_ALLOWEDSHELLCOMMANDS "AllowedShellCommands[]")
set(MIKTEX_CONFIG_VALUE_ALLOW_UNRESTRICTED_SUPER_USER "AllowUnrestrictedSuperUser")
set(MIKTEX_CONFIG_VALUE_ALLOWUNSAFEINPUTFILES "AllowUnsafeInputFiles")
set(MIKTEX_CONFIG_VALUE_ALLOWUNSAFEOUTPUTFILES "AllowUnsafeOutputFiles")
set(MIKTEX_CONFIG_VALUE_ALTEXTENSIONS "AltExtensions[]")
set(MIKTEX_CONFIG_VALUE_AUTOADMIN "AutoAdmin")
set(MIKTEX_CONFIG_VALUE_AUTOINSTALL "AutoInstall")
set(MIKTEX_CONFIG_VALUE_COMMONLINKTARGETDIRECTORY "CommonLinkTargetDirectory")
set(MIKTEX_CONFIG_VALUE_COMMONLOGDIRECTORY "CommonLogDirectory")
set(MIKTEX_CONFIG_VALUE_COMMON_CONFIG "CommonConfig")
set(MIKTEX_CONFIG_VALUE_COMMON_DATA "CommonData")
set(MIKTEX_CONFIG_VALUE_COMMON_INSTALL "CommonInstall")
set(MIKTEX_CONFIG_VALUE_COMMON_ROOTS "CommonRoots")
set(MIKTEX_CONFIG_VALUE_CREATEAUXDIRECTORY "CreateAuxDirectory")
set(MIKTEX_CONFIG_VALUE_CREATEOUTPUTDIRECTORY "CreateOutputDirectory")
set(MIKTEX_CONFIG_VALUE_CSTYLEERRORS "CStyleErrors")
set(MIKTEX_CONFIG_VALUE_DESTDIR "DestDir")
set(MIKTEX_CONFIG_VALUE_EDITOR "Editor")
set(MIKTEX_CONFIG_VALUE_ENVVARS "EnvVars[]")
set(MIKTEX_CONFIG_VALUE_EXTENSIONS "Extensions[]")
set(MIKTEX_CONFIG_VALUE_FORCE_LOCAL_SERVER "ForceLocalServer")
set(MIKTEX_CONFIG_VALUE_GUI_FRAMEWORK "GUIFramework")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_DIAGNOSE "LastAdminDiagnose")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_MAINTENANCE "LastAdminMaintenance")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE "LastAdminUpdate")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE_CHECK "LastAdminUpdateCheck")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE_DB "LastAdminUpdateDb")
set(MIKTEX_CONFIG_VALUE_LAST_USER_DIAGNOSE "LastUserDiagnose")
set(MIKTEX_CONFIG_VALUE_LAST_USER_MAINTENANCE "LastUserMaintenance")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE "LastUserUpdate")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE_CHECK "LastUserUpdateCheck")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE_DB  "LastUserUpdateDb")
set(MIKTEX_CONFIG_VALUE_LOCAL_REPOSITORY "LocalRepository")
set(MIKTEX_CONFIG_VALUE_MIKTEXDIRECT_ROOT "MiKTeXDirectRoot")
set(MIKTEX_CONFIG_VALUE_NO_REGISTRY "NoRegistry")
set(MIKTEX_CONFIG_VALUE_OTHER_COMMON_ROOTS "OtherCommonRoots")
set(MIKTEX_CONFIG_VALUE_OTHER_USER_ROOTS "OtherUserRoots")
set(MIKTEX_CONFIG_VALUE_PARSE_FIRST_LINE "ParseFirstLine")
set(MIKTEX_CONFIG_VALUE_PATHS "Paths[]")
set(MIKTEX_CONFIG_VALUE_PK_FN_TEMPLATE "PKFnTemplate")
set(MIKTEX_CONFIG_VALUE_PROXY_AUTH_REQ "ProxyAuthReq")
set(MIKTEX_CONFIG_VALUE_PROXY_HOST "ProxyHost")
set(MIKTEX_CONFIG_VALUE_PROXY_PORT "ProxyPort")
set(MIKTEX_CONFIG_VALUE_REMOTE_REPOSITORY "RemoteRepository")
set(MIKTEX_CONFIG_VALUE_REMOTE_SERVICE "RemoteService_${MIKTEX_J2000_VERSION}")
set(MIKTEX_CONFIG_VALUE_RENEW_FORMATS_ON_UPDATE "RenewFormatsOnUpdate")
set(MIKTEX_CONFIG_VALUE_REPOSITORY_RELEASE_STATE "RepositoryReleaseState")
set(MIKTEX_CONFIG_VALUE_REPOSITORY_TYPE "RepositoryType")
set(MIKTEX_CONFIG_VALUE_SHARED_SETUP "SharedSetup")
set(MIKTEX_CONFIG_VALUE_SHELLCOMMANDMODE "ShellCommandMode")
set(MIKTEX_CONFIG_VALUE_STARTUP_FILE "StartupFile")
set(MIKTEX_CONFIG_VALUE_TEMPDIR "TempDir")
set(MIKTEX_CONFIG_VALUE_TRACE "Trace")
set(MIKTEX_CONFIG_VALUE_USERINFO_FILE "UserInfoFile")
set(MIKTEX_CONFIG_VALUE_USERLINKTARGETDIRECTORY "UserLinkTargetDirectory")
set(MIKTEX_CONFIG_VALUE_USERLOGDIRECTORY "UserLogDirectory")
set(MIKTEX_CONFIG_VALUE_USER_CONFIG "UserConfig")
set(MIKTEX_CONFIG_VALUE_USER_DATA "UserData")
set(MIKTEX_CONFIG_VALUE_USER_INSTALL "UserInstall")
set(MIKTEX_CONFIG_VALUE_USER_ROOTS "UserRoots")
set(MIKTEX_CONFIG_VALUE_USE_PROXY "UseProxy")

==> miktex-20.6.tar.xz: miktex-20.6/cmake/modules/ConfigNames.cmake <==
## ConfigNames.cmake
##
## Copyright (C) 2017-2020 Christian Schenk
## 
## This file is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; either version 2, or (at your
## option) any later version.
## 
## This file is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this file; if not, write to the Free Software
## Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
## USA.

set(MIKTEX_CONFIG_SECTION_AUTO "Auto")
set(MIKTEX_CONFIG_SECTION_BIBTEX "BibTeX")
set(MIKTEX_CONFIG_SECTION_CORE "Core")
set(MIKTEX_CONFIG_SECTION_CORE_FILETYPES "${MIKTEX_CONFIG_SECTION_CORE}.FileTypes")
set(MIKTEX_CONFIG_SECTION_GENERAL "General")
set(MIKTEX_CONFIG_SECTION_MAKEBASE "MakeBase")
set(MIKTEX_CONFIG_SECTION_MAKEFMT "MakeFMT")
set(MIKTEX_CONFIG_SECTION_MAKEPK "MakePk")
set(MIKTEX_CONFIG_SECTION_MAKETFM "MakeTFM")
set(MIKTEX_CONFIG_SECTION_MPM "MPM")
set(MIKTEX_CONFIG_SECTION_SETUP "Setup")
set(MIKTEX_CONFIG_SECTION_TEXANDFRIENDS "TeXandFriends")

set(MIKTEX_CONFIG_VALUE_ALLOWEDSHELLCOMMANDS "AllowedShellCommands[]")
set(MIKTEX_CONFIG_VALUE_ALLOW_UNRESTRICTED_SUPER_USER "AllowUnrestrictedSuperUser")
set(MIKTEX_CONFIG_VALUE_ALLOWUNSAFEINPUTFILES "AllowUnsafeInputFiles")
set(MIKTEX_CONFIG_VALUE_ALLOWUNSAFEOUTPUTFILES "AllowUnsafeOutputFiles")
set(MIKTEX_CONFIG_VALUE_ALTEXTENSIONS "AltExtensions[]")
set(MIKTEX_CONFIG_VALUE_AUTOADMIN "AutoAdmin")
set(MIKTEX_CONFIG_VALUE_AUTOINSTALL "AutoInstall")
set(MIKTEX_CONFIG_VALUE_COMMONLINKTARGETDIRECTORY "CommonLinkTargetDirectory")
set(MIKTEX_CONFIG_VALUE_COMMONLOGDIRECTORY "CommonLogDirectory")
set(MIKTEX_CONFIG_VALUE_COMMON_CONFIG "CommonConfig")
set(MIKTEX_CONFIG_VALUE_COMMON_DATA "CommonData")
set(MIKTEX_CONFIG_VALUE_COMMON_INSTALL "CommonInstall")
set(MIKTEX_CONFIG_VALUE_COMMON_ROOTS "CommonRoots")
set(MIKTEX_CONFIG_VALUE_CONFIG "Config")
set(MIKTEX_CONFIG_VALUE_CREATEAUXDIRECTORY "CreateAuxDirectory")
set(MIKTEX_CONFIG_VALUE_CREATEOUTPUTDIRECTORY "CreateOutputDirectory")
set(MIKTEX_CONFIG_VALUE_CSTYLEERRORS "CStyleErrors")
set(MIKTEX_CONFIG_VALUE_DESTDIR "DestDir")
set(MIKTEX_CONFIG_VALUE_EDITOR "Editor")
set(MIKTEX_CONFIG_VALUE_ENVVARS "EnvVars[]")
set(MIKTEX_CONFIG_VALUE_EXTENSIONS "Extensions[]")
set(MIKTEX_CONFIG_VALUE_FORCE_LOCAL_SERVER "ForceLocalServer")
set(MIKTEX_CONFIG_VALUE_GUI_FRAMEWORK "GUIFramework")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_DIAGNOSE "LastAdminDiagnose")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_MAINTENANCE "LastAdminMaintenance")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE "LastAdminUpdate")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE_CHECK "LastAdminUpdateCheck")
set(MIKTEX_CONFIG_VALUE_LAST_ADMIN_UPDATE_DB "LastAdminUpdateDb")
set(MIKTEX_CONFIG_VALUE_LAST_USER_DIAGNOSE "LastUserDiagnose")
set(MIKTEX_CONFIG_VALUE_LAST_USER_MAINTENANCE "LastUserMaintenance")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE "LastUserUpdate")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE_CHECK "LastUserUpdateCheck")
set(MIKTEX_CONFIG_VALUE_LAST_USER_UPDATE_DB  "LastUserUpdateDb")
set(MIKTEX_CONFIG_VALUE_LOCAL_REPOSITORY "LocalRepository")
set(MIKTEX_CONFIG_VALUE_MIKTEXDIRECT_ROOT "MiKTeXDirectRoot")
set(MIKTEX_CONFIG_VALUE_NO_REGISTRY "NoRegistry")
set(MIKTEX_CONFIG_VALUE_OTHER_COMMON_ROOTS "OtherCommonRoots")
set(MIKTEX_CONFIG_VALUE_OTHER_USER_ROOTS "OtherUserRoots")
set(MIKTEX_CONFIG_VALUE_PARSE_FIRST_LINE "ParseFirstLine")
set(MIKTEX_CONFIG_VALUE_PATHS "Paths[]")
set(MIKTEX_CONFIG_VALUE_PK_FN_TEMPLATE "PKFnTemplate")
set(MIKTEX_CONFIG_VALUE_PROXY_AUTH_REQ "ProxyAuthReq")
set(MIKTEX_CONFIG_VALUE_PROXY_HOST "ProxyHost")
set(MIKTEX_CONFIG_VALUE_PROXY_PORT "ProxyPort")
set(MIKTEX_CONFIG_VALUE_REMOTE_REPOSITORY "RemoteRepository")
string(RANDOM rand)
set(MIKTEX_CONFIG_VALUE_REMOTE_SERVICE "RemoteService_${rand}")
set(MIKTEX_CONFIG_VALUE_RENEW_FORMATS_ON_UPDATE "RenewFormatsOnUpdate")
set(MIKTEX_CONFIG_VALUE_REPOSITORY_RELEASE_STATE "RepositoryReleaseState")
set(MIKTEX_CONFIG_VALUE_REPOSITORY_TYPE "RepositoryType")
set(MIKTEX_CONFIG_VALUE_SHARED_SETUP "SharedSetup")
set(MIKTEX_CONFIG_VALUE_SHELLCOMMANDMODE "ShellCommandMode")
set(MIKTEX_CONFIG_VALUE_STARTUP_FILE "StartupFile")
set(MIKTEX_CONFIG_VALUE_TEMPDIR "TempDir")
set(MIKTEX_CONFIG_VALUE_TRACE "Trace")
set(MIKTEX_CONFIG_VALUE_USERINFO_FILE "UserInfoFile")
set(MIKTEX_CONFIG_VALUE_USERLINKTARGETDIRECTORY "UserLinkTargetDirectory")
set(MIKTEX_CONFIG_VALUE_USERLOGDIRECTORY "UserLogDirectory")
set(MIKTEX_CONFIG_VALUE_USER_CONFIG "UserConfig")
set(MIKTEX_CONFIG_VALUE_USER_DATA "UserData")
set(MIKTEX_CONFIG_VALUE_USER_INSTALL "UserInstall")
set(MIKTEX_CONFIG_VALUE_USER_ROOTS "UserRoots")
set(MIKTEX_CONFIG_VALUE_USE_PROXY "UseProxy")
set(MIKTEX_CONFIG_VALUE_VERSION "Version")
